:py:mod:`piel.models.frequency.photonic.defaults`
=================================================

.. py:module:: piel.models.frequency.photonic.defaults


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.frequency.photonic.defaults.get_default_models



.. py:function:: get_default_models() -> dict

   Returns the default models dictionary.

   :returns: Default models dictionary.
   :rtype: dict
